% ----------------------------
% Two-Legged Passive Dynamic Walking
% March 31, 2011
% ----------------------------
clear all;

global d l r w m Ig g gamma;

%% SIMULATION CONTROL
STEPS = 1;
SHOW_ENERGY = 1;

%% PHYSICAL PARAMETERS OF THE WALKER
d = 0;        % length along leg from H to CG [m]
l = 0;        % length along leg from CG to foot [m]
r = 0;        % radius of the foot [m]
w = 0;        % perpendicular offset of the CG from the leg [m]
m = 0;        % mass of each leg [kg]
Ig = 0;       % mass moment of inertia of the leg [kg-m^2]

%% PHYSICAL PARAMETERS OF THE ENVIRONMENT
g = 9.81;       % acceleration due to gravity [N/m^2]
gamma = 0;   % slope angle [radians]

%% INITIAL CONDITIONS & SETUP
t_s = 0;        % stance leg angle [rad]
t_f = 0;     % free leg angle [rad]
w_s = 0;      % stance leg angular velocity [rad/s]
w_f = 0;       % free leg angular velocity [rad/s]

% BUILD SOME VECTORS (FROM-TO)
%>>

% CALCULATE INITIAL VELOCITIES
%>>

% INITIALIZE ODE45
ODEinit = [];
ODEstop = 5; % max time to achieve heelstrike
ODEmaxstep = 0.005;
ODEoptions = odeset('MaxStep',ODEmaxstep,'Events',@pdw_events); % use an event handler to detect heelstrikes

%% RUN THE SIMULATION
t=0;
for(rounds=1:STEPS)
    
    [t,X,TE,YE,IE] = ode45(@pdw_equations,[t(end) t(end)+ODEstop],ODEinit,ODEoptions);

    % PLOT THE MOTION
    tplot = t(1):0.02:t(end);
    Xplot = interp1(t,X,tplot);
    pdw_plot([tplot'; t(end)],[Xplot; X(end,:)]);
    
    % PLOT THE ENERGY OF THE SYSTEM
    pdw_energy(t,X);

    % assuming that the heelstrike is a perfectly inelastic collision, that
    % gravity has little effect over the duration of impact, and that the
    % hip joint is frictionless, we can apply conservation of angular
    % momentum!

    % SWAP POSITIONS AND ANGLES
    %>>
    
    % BUILD SOME VECTORS (FROM-TO)
    %>>
    
    % CALCULATE pre-impact angular momentum of the full system about point C
    %>>
    
    % CALCULATE pre-impact angular momentum of the new swing leg about point H
    %>>
    
    % solve using linear algebra:
    %>>
    
    % reset initial conditions for the next round of ode45
    %>>

end