function pdw_plot(t,X)
% ----------------------------
% Two-Legged Passive Dynamic Walking
% March 31, 2011
%
% Graphics subroutine
% ----------------------------

global d l r w m Ig g gamma;

figure(98);
if(t(1)==0)
    clf; hold on; axis equal;
end

%% CONTROL PARAMETERS
SLOPE = [-1.5 4];
LIGHTEN = 0.9;

%% RECONSTRUCT LINK GEOMETRY (IN THE XY FRAME)
H = [X(:,13) X(:,14)];

T_S = X(:,3);
S = [X(:,1) X(:,2)];
A = H + ((d+l-r) * [sin(T_S) -cos(T_S)]);
B = H + ((d+l) * [sin(T_S) -cos(T_S)]);
C = A + [zeros(length(t),1) -r*ones(length(t),1)];
D = H + ((d) * [sin(T_S) -cos(T_S)]);

T_F = X(:,9);
F = [X(:,7) X(:,8)];
M = H + ((d+l-r) * [sin(T_F) -cos(T_F)]);
N = H + ((d+l) * [sin(T_F) -cos(T_F)]);
O = M + [zeros(length(t),1) -r*ones(length(t),1)];
P = H + ((d) * [sin(T_F) -cos(T_F)]);

%% ROTATE BY GAMMA TO GET INTO THE WORLD FRAME
RGW = [cos(gamma) sin(gamma); -sin(gamma) cos(gamma)];

H = (RGW*H')';
S = (RGW*S')';
A = (RGW*A')';
B = (RGW*B')';
C = (RGW*C')';
D = (RGW*D')';
F = (RGW*F')';
M = (RGW*M')';
N = (RGW*N')';
O = (RGW*O')';
P = (RGW*P')';

%% PLOT THE SLOPE
if(t(1)==0)
    SX = [C(1,1)+SLOPE(1)*cos(gamma); C(1,1)+SLOPE(2)*cos(gamma)];
    SY = [C(1,2)-SLOPE(1)*sin(gamma); C(1,2)-SLOPE(2)*sin(gamma)];
    h=plot(SX,SY,'k');
    set(h,'Color',[0.5 0.5 0.5]);
end

%% PLOT THE WALKER
for(i=1:length(t))

    % LIGHTEN THE PAST POSITIONS
    if(i>1)
        for(y=1:4)
            set(h(y),'Color',[1 LIGHTEN LIGHTEN],'LineWidth',0.25);
        end
        for(y=5:8)
            set(h(y),'Color',[LIGHTEN LIGHTEN 1],'LineWidth',0.25);
        end
        set(h(9),'Color',[LIGHTEN LIGHTEN LIGHTEN],'LineWidth',0.25);
    end

    % STANCE LEG (ALWAYS RED)
    h(1)=plot([H(i,1) B(i,1)],[H(i,2) B(i,2)],'r');          % leg
    h(2)=plot([D(i,1) S(i,1)],[D(i,2) S(i,2)],'r');          % CG extension
    h(3)=arc([A(i,1),A(i,2)],r,[T_S(i)+3.5 T_S(i)+5.8],'r'); % foot
    h(4)=plot([S(i,1)],[S(i,2)],'ro');                       % CG marker

    % FREE LEG (ALWAYS BLUE)
    h(5)=plot([H(i,1) N(i,1)],[H(i,2) N(i,2)]);              % leg
    h(6)=plot([P(i,1) F(i,1)],[P(i,2) F(i,2)]);              % CG extension
    h(7)=arc([M(i,1),M(i,2)],r,[T_F(i)+3.5 T_F(i)+5.8],'b'); % foot
    h(8)=plot([F(i,1)],[F(i,2)],'o');                        % CG

    h(9)=plot(C(i,1),C(i,2),'kd');                           % contact point
   
    title(t(i)) % display the time in the title
    pause(0.02)
end
